/**
 * Created by ilia on 11/1/2016.
 */

/**
 * 1
 * Copyright Qnext Inc. 2002-2013
 * http://www.qnext.com
 * Date: 08/12/13
 * Time: 11:24 AM
 * Author Greg Wade (gregw@qnext.com)
 */


$(document).ready(function() {

    var checkboxNetworkBrowsing = document.getElementById("network-browsing");
    var $buttonSave = $("#saveButton").attr("disabled", true);
    var buttonCancel = document.getElementById("activButtonCancel");

    // Hide "Cancel" and "Done" buttons for browsers
    if (APP_TYPE === "native") {
        buttonCancel.style.display = 'inline-block';
    } else {
        buttonCancel.style.display = 'none';
    }

    //Set default states
    checkboxNetworkBrowsing.checked=false;
    checkboxNetworkBrowsing.focus();


    // Add click handlers
    checkboxNetworkBrowsing.addEventListener("click", checkboxClick);

    initializeLanguage("/locales/__ns__-__lng__.json", function() {
        psvFetchStatus(function(statusInfo) {
            if(isSecured()) {
                setGlobals(statusInfo);

                // stop 'secureonly' css fields from being hidden
                $('.secureonly').removeClass('secureonly');

                displayStatus(statusInfo);
                addFocusHandler("network-browsing", true);// set autofocus
            } else {
                // if we're not secured, we redirect the user to the secured version of this page
                var securedUrl = generateSecuredUrl();
                log("eventually redirecting user to " + securedUrl);
                redirectUserEventually(securedUrl, REDIRECT_SECONDS);
            }
        });
    });

    // render the status in terms of a message, and highlighting errors
    function showUpdateMessage(msg) {
        // remove previous errors using jquery - search for alerts? it will do
        $("#updatemsg .alert").remove();

        // add the error/success message and highlights
        $("#updatemsg").append("<div class='alert alert-warning'>" + msg + "</div>");
    }

   // function to update a settings
    function psvSettingsUpdate(onSuccess, onFailure) {

        var params = {
            "cmd": "set-global",
            "network-enabled": document.getElementById("network-browsing").checked
        };

        var requestUrl = addParams("/secure/", params);

        $.get(requestUrl)
            .done(function(resp) {
                if (resp.result) {
                    onSuccess(resp.redirectURL);
                    log("psvSettingsUpdate success updating settings");
                    showMessage(ERROR_OK, $.t("settings_success"));
                } else {
                    log("psvSettingsUpdate failure updating settings: " + resp.msg);
                    var code = translateMsgToErrorCode(resp.msg);
                    onFailure(code);
                }
            })
            .fail(function(xhr, err) {
                onFailure(getError(xhr, err));
            });
    }

// function to fetch the status of the device
// returns status info as JSON to the onSuccess function, in the format of:
//{
//    "version": "2.0.0",
//    "build": "2.0.0",
//    "updateable": false,
//    "debug": true,
//    "connected": false,
//    "thumbnails": true
//}
    function psvFetchStatus(onSuccess) {

        var params = {
            "cmd": "status"
        };

        var requestUrl = addParams("/secure/", params);

        $.get(requestUrl)
            .done(function(resp) {
                log("fetchStatus success with: ");
                log(resp);

                var networkBrowsing = resp['network-enabled'];

                if (networkBrowsing) {
                    document.getElementById("network-browsing").checked=true;
                } else {
                    document.getElementById("network-browsing").checked=false;
                }

                onSuccess(resp);
            })
            .fail(function() {
                log("fetchStatus failure with " + code);
            });
    }

// function to Disable/Enable input controls after Activate button clicked
    function activeButtonOnOff(onDisable) {

        if (onDisable) {
            $buttonSave.attr("disabled", true);
        } else {
            $buttonSave.removeAttr("disabled");
        }

    }

    $buttonSave.click(function (e) {
        e.preventDefault();

        activeButtonOnOff(true);

        // proceed with the settings update attempt
        psvSettingsUpdate(function(redirectURL) {
            // success
            log("settings update successful");

            activeButtonOnOff(false);

            $buttonSave.attr("disabled", true);

            // indicate success visually

            log("redirectURL found: " + redirectURL);

            // if a redirect URL was provided by passive (via the server) we use it to send the user back immediately
            if (redirectURL != null) {
                // if there is a redirect URL, we immediately redirect the user
                log("redirectURL found: " + redirectURL);
                window.location.href = redirectURL;
            } else {
                log("no redirect URL was found");
            }

        }, function(code) {
            activeButtonOnOff(false);
            translateErrorCode(code);
        });
    });


    function showBool(v) {
        if (v) {
            return $.t("true_value");
        } else {
            return $.t("false_value");
        }
    }

    function displayStatus(statusInfo) {
        var $version = $("#version");
        var verString = $.t("app_version", {ver : statusInfo.version});
        $version.text(verString);
        var extraInfo = $.t("tooltip_build") + ': ' + statusInfo.build;
        extraInfo+= '\n' + $.t("tooltip_version") + ': ' + statusInfo.version;
        extraInfo+= '\n' + $.t("tooltip_debug") + ': ' + showBool(statusInfo.debug);
        extraInfo+= '\n' + $.t("tooltip_updateable") + ': ' + showBool(statusInfo.updateable);
        extraInfo+= '\n' + $.t("tooltip_connected") + ': ' + showBool(statusInfo.connected);
        extraInfo+= '\n' + $.t("tooltip_thumbnails") + ': ' + showBool(statusInfo.thumbnails);

        $version.prop('title', extraInfo);

        if (!statusInfo.updateable) {
            log("updates are disabled!");
            showUpdateMessage($.t("updates_disabled_body"));
        }
    }

    function checkboxClick() {
        $buttonSave.removeAttr("disabled");
    }
});







